MessagePassingRepresentation
============================

.. currentmodule:: pykeen.nn.pyg

.. autoclass:: MessagePassingRepresentation
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MessagePassingRepresentation.pass_messages

   .. rubric:: Methods Documentation

   .. automethod:: pass_messages
